## `py_antilibrary` - API Client for antilibrary.xyz

This package is [released on PyPi](https://pypi.org/project/py-antilibrary/).

### Usage

```python
antilibrary = py_antilibrary.Client()

b = antilibrary.get_book(id=2)
```
